/* ***************
// Desc: JS File for QuickPrefs, this is where all the loading and saving of the file is.
// Modified version of ChromEdit's .js file by Chris Neale (Cdn@mozdev.org)
// 
// Author: Jed Brown (jedbro@gmx.net)
// Version: 0.1.3
// Last modified: June 22nd, 2003
****************** */

function closeWindow()
{
  window.close();
}

function getTextareaText(tNodeID) {
	var tat = document.getElementById(tNodeID).value
	return tat
}

function setTextareaText(thetext,tNodeID) {
	document.getElementById(tNodeID).value= thetext
}

////////////////////////////////////////////////////////////////////////////////
// saveIt
//
// Desc: Loads the files
// Parameters: fileName: The name of the file to save two. targetNodeID: Where it is headed to (onePad, twoPad)
// Returns: nothing
////////////////////////////////////////////////////////////////////////////////
function loadIt(fileName,targetNodeID) {
	var d = new DirUtils;
	var p = d.getUserChromeDir();
	var fName = fileName;
	var f = new File(p);
	var target = f.nsIFile;
	var target2 = target;
	target.append(fName);
	
	f=new File(target.path);
	
	//If file already exists then just open it.
	if (f.exists()) {
		f.open()
		var stuff=f.read()
		f.close()
		setTextareaText(stuff,targetNodeID);
	}
	
	// If it doesn't exist, create the file, then make sure it exists, then open.
	else if (!f.exists() ) { 	
		f.create();
		
		if (f.exists()) {
			f.open()
			var stuff=f.read()
			f.close()
			setTextareaText(stuff,targetNodeID);
		}
		else {setTextareaText('// #2 Currently you do not have a user.js file.',targetNodeID)}
		
	}
	else {setTextareaText('// #1 Currently you do not have a user.js file.',targetNodeID)}
	
}

////////////////////////////////////////////////////////////////////////////////
// saveIt
//
// Desc: Saves the file using JSlib DirUtils and File
// Parameters: fileName: The name of the file to save two. targetNodeID: Where it is headed to (onePad, twoPad). button: Which save button this affects!
// Returns: nothing
// To-Do: Merge saveIt and saveAFile. Stupid to have both!
////////////////////////////////////////////////////////////////////////////////
function saveIt(fileName,targetNodeID,button) {
	var data = getTextareaText(targetNodeID);
	var d = new DirUtils;
	var p = d.getUserChromeDir();
	var fName = fileName;
	var f = new File(p);
	var target = f.nsIFile;
	target.append(fName);  
	f=new File(target.path);
	
	f.open('w')
	p = f.write(data)
	f.close()
	
	if(p)
		document.getElementById(button).setAttribute("disabled", "true");
	
}

////////////////////////////////////////////////////////////////////////////////
// saveIfChanged
//
// Desc: Auto-save function!
// Parameters: none
// Returns: nothing
////////////////////////////////////////////////////////////////////////////////
function saveIfChanged() {

    if ( ! document.getElementById('save-one').hasAttribute('disabled') )
      saveIt('quicknote1.txt','onePad');

    if ( ! document.getElementById('save-two').hasAttribute('disabled') )
      saveIt('quicknote2.txt','twoPad');

}


////////////////////////////////////////////////////////////////////////////////
// OnLoad
//
// Desc: Make sure this loads with QuickNote to get the onePad data
// Parameters: onePad to copy the selection (via arguments[0])
// Returns: nothing
////////////////////////////////////////////////////////////////////////////////
var onePad;  // textbox holding the text to copy from onePad

function OnLoad() {
  onePad = document.getElementById("onePad");
  //onePad.value = window.arguments[0];
  onePad.value = onePad.value+"\n";
  onePad.value = onePad.value+window.arguments[0];
  //onePad.value = onePad.value.replace(/\n\n/g,"\n");
  document.getElementById('save-one').removeAttribute('disabled');
  sizeToContent();
  onePad.focus();
}

//**** SaveAS and FilePicker ******

////////////////////////////////////////////////////////////////////////////////
// txtFilePicker
//
// Parameters:
//  aTitle: title to go on file picker window
//  aSave: 1 if picking file to save/overwrite, 0 if picking file to load
//  aStart: directory to start from
//    This must be an nsILocalFile.  new Dir("foo") in jslib/io/dir.js will
//    do the trick, but you have to do it yourself.
// Returns:
//  Name of file picked, in URL format, or null if cancelled
// Original taken and modified from Tagzilla.mozdev.org!
////////////////////////////////////////////////////////////////////////////////
function txtFilePicker(aTitle, aSave) {
  var retVal = null;
  try {
   
    const nsIFilePicker = Components.interfaces.nsIFilePicker;
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
    fp.init(window, aTitle, (aSave ? nsIFilePicker.modeSave : nsIFilePicker.modeOpen));
    fp.appendFilters(nsIFilePicker.filterAll | nsIFilePicker.filterText);
    
    /*
    if(aStart) {
      fp.displayDirectory = aStart;
    }
    */
    var result=fp.show();
    if (result == nsIFilePicker.returnOK || result == nsIFilePicker.returnReplace) {
      //retVal=fp.fileURL.spec;
      retVal=fp.file.path;
      //alert("Should return retval: "+retVal+" YES!"); // DEBUG
    }
  }
  catch (ex) {
  }
  return retVal;
}

////////////////////////////////////////////////////////////////////////////////
// saveListAs
//
// Parameters: targetNodeID: What to save
// button: Which button was pressed
// Returns: true if list saved, false otherwise
// Original taken and modified from Tagzilla.mozdev.org!
////////////////////////////////////////////////////////////////////////////////
function saveListAs(targetNodeID, button) {
  var d = new DirUtils;
  var myUserDirPlease = d.getUserChromeDir();
  var targetNodeID2 = targetNodeID;
  var fName = txtFilePicker("Save the File as",1,myUserDirPlease);
  if(fName==null){
    return false;
  }
  
  var isSaved = saveAFile(fName, targetNodeID2, button);
  //if(isSaved){
	//document.getElementById(button).setAttribute("disabled", "true");
  //}
  return isSaved;
}

////////////////////////////////////////////////////////////////////////////////
// saveAFile
//
// Parameters:
//  aUrl: string name of file to open, in platform-specific or file:// format
//  targetNodeID: where the data is to save!
//  button: The button that makes the call (for disable/enable)
// Returns: true if list saved, false otherwise
// To-Do: Merge saveIt and saveAFile. Stupid to have both!
////////////////////////////////////////////////////////////////////////////////
function saveAFile(aUrl, targetNodeID, button) {

  var aFile=aUrl;
  if(aUrl.substring(0,4)=="file") {
    var fUtils = new FileUtils();
    aFile = fUtils.urlToPath(aUrl);
  }

  var f = new File(aFile);
  if(!f.open("w")) {
    alert("File could not be opened!");
    return false;
  }
  //f.write(tzList.join("\n")+"\n");
  var data = getTextareaText(targetNodeID);
  f.write(data);
  f.close();

  //document.getElementById(button).setAttribute("disabled", "true");
  return true;
}

//**** MAKE SURE THAT When 'SENDING TO QN' you don't get multiple windows!! **/

